==> syncope-1.2.11-source-release.zip: syncope-1.2.11/installer/src/main/java/org/apache/syncope/installer/enums/Containers.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.installer.enums;

public enum Containers {

    TOMCAT("tomcat"),
    JBOSS("jboss"),
    GLASSFISH("glassfish");

    private Containers(final String name) {
        this.name = name;
    }

    private final String name;

    public String getName() {
        return name;
    }

    public static Containers fromContainerName(final String containerName) {
        Containers container = null;
        if (TOMCAT.getName().equalsIgnoreCase(containerName)) {
            container = TOMCAT;
        } else if (JBOSS.getName().equalsIgnoreCase(containerName)) {
            container = JBOSS;
        } else if (GLASSFISH.getName().equalsIgnoreCase(containerName)) {
            container = GLASSFISH;
        }
        return container;
    }

}

==> syncope-2.1.12-source-release.zip: syncope-2.1.12/installer/src/main/java/org/apache/syncope/installer/enums/Containers.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.syncope.installer.enums;

public enum Containers {

    TOMCAT("tomcat"),
    JBOSS("jboss"),
    GLASSFISH("glassfish");

    Containers(final String name) {
        this.name = name;
    }

    private final String name;

    public String getName() {
        return name;
    }

    public static Containers fromContainerName(final String containerName) {
        Containers container = null;
        if (TOMCAT.getName().equalsIgnoreCase(containerName)) {
            container = TOMCAT;
        } else if (JBOSS.getName().equalsIgnoreCase(containerName)) {
            container = JBOSS;
        } else if (GLASSFISH.getName().equalsIgnoreCase(containerName)) {
            container = GLASSFISH;
        }
        return container;
    }

}
